Module cookbook

Module cookbook 

Deterministic cookbook builders for math view recipes.

Functions

heatmap_grid_demo
Build the domain-neutral masked heatmap Scene used by the cookbook recipe.
plot_series_demo
Build the plot Scene used by the cookbook recipe.